Index: trunk/psLib/src/math/psEllipse.h
===================================================================
--- trunk/psLib/src/math/psEllipse.h	(revision 19996)
+++ trunk/psLib/src/math/psEllipse.h	(revision 36375)
@@ -38,5 +38,5 @@
 } psEllipseShape;
 
-/// Ellipse defined in terms of polarisations
+/// Ellipse defined in terms of polarizations
 typedef struct {
     double e0;                          ///< Scale (Mxx + Myy)
@@ -65,18 +65,20 @@
                                    );
 
 /// Convert axes to polarisation representation
 psEllipsePol psEllipseAxesToPol(psEllipseAxes axes ///< Axes of ellipse
                                 );
 
-/// Convert shape to polarisation representation
+/// Convert polarization to axes representation
+psEllipseAxes psEllipsePolToAxes(const psEllipsePol pol, ///< Polarization of ellipse
+				 const float minMinorAxis ///< Minimum allowed minor axis
+    );
+
+/// Convert shape to polarization representation
 psEllipsePol psEllipseShapeToPol(psEllipseShape shape ///< Shape of ellipse
                                  );
 
-/// Convert polarisation to axes representation
-///
-/// XXX This API goes against the PS convention of outputs being first.
-psEllipseAxes psEllipsePolToAxes(const psEllipsePol pol, ///< Polarisation of ellipse
-				 const float minMinorAxis ///< Minimum allowed minor axis
-    );
+/// Convert shape to polarization representation
+psEllipseShape psEllipsePolToShape(psEllipsePol pol ///< Shape of ellipse
+                                 );
 
 /// @}
@@ -65,18 +65,20 @@
                                    );
 
-/// Convert axes to polarisation representation
+/// Convert axes to polarization representation
 psEllipsePol psEllipseAxesToPol(psEllipseAxes axes ///< Axes of ellipse
                                 );
